@@ -12,7 +12,7 @@ test_that(
     regexp = glue::glue(
       "NCAA can be used in the following functions: geom_baseball(), ",
       "geom_basketball(), geom_football(), geom_hockey(), geom_soccer(), ",
-      "or geom_tennis()"
+      "geom_tennis(), or geom_volleyball()"
     )
   )
   expect_message(
@@ -58,15 +58,6 @@ test_that(
     fixed = TRUE,
     regexp = "A plot for NFL can be created via the geom_football() function"
   )
-
-  expect_message(
-    cani_plot_sport("curling"),
-    fixed = TRUE,
-    regexp = glue::glue(
-      "A plot for curling can be created via the geom_curling() function ",
-      "for the following league: WCF"
-    )
-  )
 })
 
 test_that("cani_color_league_features() returns message on success", {
